package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringCityInfoVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringCityInfoBo;
import com.ruoyi.zdsz.service.IZEngineeringCityInfoService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 市政工程详情
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringCityInfo")
public class ZEngineeringCityInfoController extends BaseController {

    private final IZEngineeringCityInfoService iZEngineeringCityInfoService;

    /**
     * 查询市政工程详情列表
     */
    @SaCheckPermission("zdsz:engineeringCityInfo:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringCityInfoVo> list(ZEngineeringCityInfoBo bo, PageQuery pageQuery) {
        return iZEngineeringCityInfoService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出市政工程详情列表
     */
    @SaCheckPermission("zdsz:engineeringCityInfo:export")
    @Log(title = "市政工程详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringCityInfoBo bo, HttpServletResponse response) {
        List<ZEngineeringCityInfoVo> list = iZEngineeringCityInfoService.queryList(bo);
        ExcelUtil.exportExcel(list, "市政工程详情", ZEngineeringCityInfoVo.class, response);
    }

    /**
     * 获取市政工程详情详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringCityInfo:query")
    @GetMapping("/{id}")
    public R<ZEngineeringCityInfoVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringCityInfoService.queryById(id));
    }

    /**
     * 新增市政工程详情
     */
    @SaCheckPermission("zdsz:engineeringCityInfo:add")
    @Log(title = "市政工程详情", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringCityInfoBo bo) {
        return toAjax(iZEngineeringCityInfoService.insertByBo(bo));
    }

    /**
     * 修改市政工程详情
     */
    @SaCheckPermission("zdsz:engineeringCityInfo:edit")
    @Log(title = "市政工程详情", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringCityInfoBo bo) {
        return toAjax(iZEngineeringCityInfoService.updateByBo(bo));
    }

    /**
     * 删除市政工程详情
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringCityInfo:remove")
    @Log(title = "市政工程详情", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringCityInfoService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
