package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringCivilInfoVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringCivilInfoBo;
import com.ruoyi.zdsz.service.IZEngineeringCivilInfoService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 民用工程详情信息
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringCivilInfo")
public class ZEngineeringCivilInfoController extends BaseController {

    private final IZEngineeringCivilInfoService iZEngineeringCivilInfoService;

    /**
     * 查询民用工程详情信息列表
     */
    @SaCheckPermission("zdsz:engineeringCivilInfo:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringCivilInfoVo> list(ZEngineeringCivilInfoBo bo, PageQuery pageQuery) {
        return iZEngineeringCivilInfoService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出民用工程详情信息列表
     */
    @SaCheckPermission("zdsz:engineeringCivilInfo:export")
    @Log(title = "民用工程详情信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringCivilInfoBo bo, HttpServletResponse response) {
        List<ZEngineeringCivilInfoVo> list = iZEngineeringCivilInfoService.queryList(bo);
        ExcelUtil.exportExcel(list, "民用工程详情信息", ZEngineeringCivilInfoVo.class, response);
    }

    /**
     * 获取民用工程详情信息详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringCivilInfo:query")
    @GetMapping("/{id}")
    public R<ZEngineeringCivilInfoVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringCivilInfoService.queryById(id));
    }

    /**
     * 新增民用工程详情信息
     */
    @SaCheckPermission("zdsz:engineeringCivilInfo:add")
    @Log(title = "民用工程详情信息", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringCivilInfoBo bo) {
        return toAjax(iZEngineeringCivilInfoService.insertByBo(bo));
    }

    /**
     * 修改民用工程详情信息
     */
    @SaCheckPermission("zdsz:engineeringCivilInfo:edit")
    @Log(title = "民用工程详情信息", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringCivilInfoBo bo) {
        return toAjax(iZEngineeringCivilInfoService.updateByBo(bo));
    }

    /**
     * 删除民用工程详情信息
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringCivilInfo:remove")
    @Log(title = "民用工程详情信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringCivilInfoService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
