package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringBo;
import com.ruoyi.zdsz.service.IZEngineeringService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工程管理
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineering")
public class ZEngineeringController extends BaseController {

    private final IZEngineeringService iZEngineeringService;

    /**
     * 查询工程管理列表
     */
    @SaCheckPermission("zdsz:engineering:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringVo> list(ZEngineeringBo bo, PageQuery pageQuery) {
        return iZEngineeringService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出工程管理列表
     */
    @SaCheckPermission("zdsz:engineering:export")
    @Log(title = "工程管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringBo bo, HttpServletResponse response) {
        List<ZEngineeringVo> list = iZEngineeringService.queryList(bo);
        ExcelUtil.exportExcel(list, "工程管理", ZEngineeringVo.class, response);
    }

    /**
     * 获取工程管理详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineering:query")
    @GetMapping("/{id}")
    public R<ZEngineeringVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringService.queryById(id));
    }

    /**
     * 新增工程管理
     */
    @SaCheckPermission("zdsz:engineering:add")
    @Log(title = "工程管理", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringBo bo) {
        return toAjax(iZEngineeringService.insertByBo(bo));
    }

    /**
     * 修改工程管理
     */
    @SaCheckPermission("zdsz:engineering:edit")
    @Log(title = "工程管理", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringBo bo) {
        return toAjax(iZEngineeringService.updateByBo(bo));
    }

    /**
     * 删除工程管理
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineering:remove")
    @Log(title = "工程管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
