package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringDangerInfoVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringDangerInfoBo;
import com.ruoyi.zdsz.service.IZEngineeringDangerInfoService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 危险作业工程
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringDangerInfo")
public class ZEngineeringDangerInfoController extends BaseController {

    private final IZEngineeringDangerInfoService iZEngineeringDangerInfoService;

    /**
     * 查询危险作业工程列表
     */
    @SaCheckPermission("zdsz:engineeringDangerInfo:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringDangerInfoVo> list(ZEngineeringDangerInfoBo bo, PageQuery pageQuery) {
        return iZEngineeringDangerInfoService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出危险作业工程列表
     */
    @SaCheckPermission("zdsz:engineeringDangerInfo:export")
    @Log(title = "危险作业工程", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringDangerInfoBo bo, HttpServletResponse response) {
        List<ZEngineeringDangerInfoVo> list = iZEngineeringDangerInfoService.queryList(bo);
        ExcelUtil.exportExcel(list, "危险作业工程", ZEngineeringDangerInfoVo.class, response);
    }

    /**
     * 获取危险作业工程详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringDangerInfo:query")
    @GetMapping("/{id}")
    public R<ZEngineeringDangerInfoVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringDangerInfoService.queryById(id));
    }

    /**
     * 新增危险作业工程
     */
    @SaCheckPermission("zdsz:engineeringDangerInfo:add")
    @Log(title = "危险作业工程", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringDangerInfoBo bo) {
        return toAjax(iZEngineeringDangerInfoService.insertByBo(bo));
    }

    /**
     * 修改危险作业工程
     */
    @SaCheckPermission("zdsz:engineeringDangerInfo:edit")
    @Log(title = "危险作业工程", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringDangerInfoBo bo) {
        return toAjax(iZEngineeringDangerInfoService.updateByBo(bo));
    }

    /**
     * 删除危险作业工程
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringDangerInfo:remove")
    @Log(title = "危险作业工程", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringDangerInfoService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
