package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringFilesVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringFilesBo;
import com.ruoyi.zdsz.service.IZEngineeringFilesService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 附件
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringFiles")
public class ZEngineeringFilesController extends BaseController {

    private final IZEngineeringFilesService iZEngineeringFilesService;

    /**
     * 查询附件列表
     */
    @SaCheckPermission("zdsz:engineeringFiles:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringFilesVo> list(ZEngineeringFilesBo bo, PageQuery pageQuery) {
        return iZEngineeringFilesService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出附件列表
     */
    @SaCheckPermission("zdsz:engineeringFiles:export")
    @Log(title = "附件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringFilesBo bo, HttpServletResponse response) {
        List<ZEngineeringFilesVo> list = iZEngineeringFilesService.queryList(bo);
        ExcelUtil.exportExcel(list, "附件", ZEngineeringFilesVo.class, response);
    }

    /**
     * 获取附件详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringFiles:query")
    @GetMapping("/{id}")
    public R<ZEngineeringFilesVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringFilesService.queryById(id));
    }

    /**
     * 新增附件
     */
    @SaCheckPermission("zdsz:engineeringFiles:add")
    @Log(title = "附件", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringFilesBo bo) {
        return toAjax(iZEngineeringFilesService.insertByBo(bo));
    }

    /**
     * 修改附件
     */
    @SaCheckPermission("zdsz:engineeringFiles:edit")
    @Log(title = "附件", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringFilesBo bo) {
        return toAjax(iZEngineeringFilesService.updateByBo(bo));
    }

    /**
     * 删除附件
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringFiles:remove")
    @Log(title = "附件", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringFilesService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
