package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringIndustrialInfoVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringIndustrialInfoBo;
import com.ruoyi.zdsz.service.IZEngineeringIndustrialInfoService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工业工程详情
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringIndustrialInfo")
public class ZEngineeringIndustrialInfoController extends BaseController {

    private final IZEngineeringIndustrialInfoService iZEngineeringIndustrialInfoService;

    /**
     * 查询工业工程详情列表
     */
    @SaCheckPermission("zdsz:engineeringIndustrialInfo:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringIndustrialInfoVo> list(ZEngineeringIndustrialInfoBo bo, PageQuery pageQuery) {
        return iZEngineeringIndustrialInfoService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出工业工程详情列表
     */
    @SaCheckPermission("zdsz:engineeringIndustrialInfo:export")
    @Log(title = "工业工程详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringIndustrialInfoBo bo, HttpServletResponse response) {
        List<ZEngineeringIndustrialInfoVo> list = iZEngineeringIndustrialInfoService.queryList(bo);
        ExcelUtil.exportExcel(list, "工业工程详情", ZEngineeringIndustrialInfoVo.class, response);
    }

    /**
     * 获取工业工程详情详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringIndustrialInfo:query")
    @GetMapping("/{id}")
    public R<ZEngineeringIndustrialInfoVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringIndustrialInfoService.queryById(id));
    }

    /**
     * 新增工业工程详情
     */
    @SaCheckPermission("zdsz:engineeringIndustrialInfo:add")
    @Log(title = "工业工程详情", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringIndustrialInfoBo bo) {
        return toAjax(iZEngineeringIndustrialInfoService.insertByBo(bo));
    }

    /**
     * 修改工业工程详情
     */
    @SaCheckPermission("zdsz:engineeringIndustrialInfo:edit")
    @Log(title = "工业工程详情", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringIndustrialInfoBo bo) {
        return toAjax(iZEngineeringIndustrialInfoService.updateByBo(bo));
    }

    /**
     * 删除工业工程详情
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringIndustrialInfo:remove")
    @Log(title = "工业工程详情", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringIndustrialInfoService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
