package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringInfrastructureInfoVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringInfrastructureInfoBo;
import com.ruoyi.zdsz.service.IZEngineeringInfrastructureInfoService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 基建工程详情
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringInfrastructureInfo")
public class ZEngineeringInfrastructureInfoController extends BaseController {

    private final IZEngineeringInfrastructureInfoService iZEngineeringInfrastructureInfoService;

    /**
     * 查询基建工程详情列表
     */
    @SaCheckPermission("zdsz:engineeringInfrastructureInfo:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringInfrastructureInfoVo> list(ZEngineeringInfrastructureInfoBo bo, PageQuery pageQuery) {
        return iZEngineeringInfrastructureInfoService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出基建工程详情列表
     */
    @SaCheckPermission("zdsz:engineeringInfrastructureInfo:export")
    @Log(title = "基建工程详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringInfrastructureInfoBo bo, HttpServletResponse response) {
        List<ZEngineeringInfrastructureInfoVo> list = iZEngineeringInfrastructureInfoService.queryList(bo);
        ExcelUtil.exportExcel(list, "基建工程详情", ZEngineeringInfrastructureInfoVo.class, response);
    }

    /**
     * 获取基建工程详情详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringInfrastructureInfo:query")
    @GetMapping("/{id}")
    public R<ZEngineeringInfrastructureInfoVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringInfrastructureInfoService.queryById(id));
    }

    /**
     * 新增基建工程详情
     */
    @SaCheckPermission("zdsz:engineeringInfrastructureInfo:add")
    @Log(title = "基建工程详情", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringInfrastructureInfoBo bo) {
        return toAjax(iZEngineeringInfrastructureInfoService.insertByBo(bo));
    }

    /**
     * 修改基建工程详情
     */
    @SaCheckPermission("zdsz:engineeringInfrastructureInfo:edit")
    @Log(title = "基建工程详情", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringInfrastructureInfoBo bo) {
        return toAjax(iZEngineeringInfrastructureInfoService.updateByBo(bo));
    }

    /**
     * 删除基建工程详情
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringInfrastructureInfo:remove")
    @Log(title = "基建工程详情", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringInfrastructureInfoService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
