package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringMaterialPresetVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringMaterialPresetBo;
import com.ruoyi.zdsz.service.IZEngineeringMaterialPresetService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工程用料预设
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringMaterialPreset")
public class ZEngineeringMaterialPresetController extends BaseController {

    private final IZEngineeringMaterialPresetService iZEngineeringMaterialPresetService;

    /**
     * 查询工程用料预设列表
     */
    @SaCheckPermission("zdsz:engineeringMaterialPreset:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringMaterialPresetVo> list(ZEngineeringMaterialPresetBo bo, PageQuery pageQuery) {
        return iZEngineeringMaterialPresetService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出工程用料预设列表
     */
    @SaCheckPermission("zdsz:engineeringMaterialPreset:export")
    @Log(title = "工程用料预设", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringMaterialPresetBo bo, HttpServletResponse response) {
        List<ZEngineeringMaterialPresetVo> list = iZEngineeringMaterialPresetService.queryList(bo);
        ExcelUtil.exportExcel(list, "工程用料预设", ZEngineeringMaterialPresetVo.class, response);
    }

    /**
     * 获取工程用料预设详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringMaterialPreset:query")
    @GetMapping("/{id}")
    public R<ZEngineeringMaterialPresetVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringMaterialPresetService.queryById(id));
    }

    /**
     * 新增工程用料预设
     */
    @SaCheckPermission("zdsz:engineeringMaterialPreset:add")
    @Log(title = "工程用料预设", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringMaterialPresetBo bo) {
        return toAjax(iZEngineeringMaterialPresetService.insertByBo(bo));
    }

    /**
     * 修改工程用料预设
     */
    @SaCheckPermission("zdsz:engineeringMaterialPreset:edit")
    @Log(title = "工程用料预设", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringMaterialPresetBo bo) {
        return toAjax(iZEngineeringMaterialPresetService.updateByBo(bo));
    }

    /**
     * 删除工程用料预设
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringMaterialPreset:remove")
    @Log(title = "工程用料预设", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringMaterialPresetService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
