package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZEngineeringPipeJackingInfoVo;
import com.ruoyi.zdsz.domain.bo.ZEngineeringPipeJackingInfoBo;
import com.ruoyi.zdsz.service.IZEngineeringPipeJackingInfoService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 顶管工程详情
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringPipeJackingInfo")
public class ZEngineeringPipeJackingInfoController extends BaseController {

    private final IZEngineeringPipeJackingInfoService iZEngineeringPipeJackingInfoService;

    /**
     * 查询顶管工程详情列表
     */
    @SaCheckPermission("zdsz:engineeringPipeJackingInfo:list")
    @GetMapping("/list")
    public TableDataInfo<ZEngineeringPipeJackingInfoVo> list(ZEngineeringPipeJackingInfoBo bo, PageQuery pageQuery) {
        return iZEngineeringPipeJackingInfoService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出顶管工程详情列表
     */
    @SaCheckPermission("zdsz:engineeringPipeJackingInfo:export")
    @Log(title = "顶管工程详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZEngineeringPipeJackingInfoBo bo, HttpServletResponse response) {
        List<ZEngineeringPipeJackingInfoVo> list = iZEngineeringPipeJackingInfoService.queryList(bo);
        ExcelUtil.exportExcel(list, "顶管工程详情", ZEngineeringPipeJackingInfoVo.class, response);
    }

    /**
     * 获取顶管工程详情详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:engineeringPipeJackingInfo:query")
    @GetMapping("/{id}")
    public R<ZEngineeringPipeJackingInfoVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZEngineeringPipeJackingInfoService.queryById(id));
    }

    /**
     * 新增顶管工程详情
     */
    @SaCheckPermission("zdsz:engineeringPipeJackingInfo:add")
    @Log(title = "顶管工程详情", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZEngineeringPipeJackingInfoBo bo) {
        return toAjax(iZEngineeringPipeJackingInfoService.insertByBo(bo));
    }

    /**
     * 修改顶管工程详情
     */
    @SaCheckPermission("zdsz:engineeringPipeJackingInfo:edit")
    @Log(title = "顶管工程详情", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZEngineeringPipeJackingInfoBo bo) {
        return toAjax(iZEngineeringPipeJackingInfoService.updateByBo(bo));
    }

    /**
     * 删除顶管工程详情
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:engineeringPipeJackingInfo:remove")
    @Log(title = "顶管工程详情", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZEngineeringPipeJackingInfoService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
