package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringCityInfoBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringCityInfoVo;
import com.ruoyi.zdsz.domain.ZEngineeringCityInfo;
import com.ruoyi.zdsz.mapper.ZEngineeringCityInfoMapper;
import com.ruoyi.zdsz.service.IZEngineeringCityInfoService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 市政工程详情Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringCityInfoServiceImpl implements IZEngineeringCityInfoService {

    private final ZEngineeringCityInfoMapper baseMapper;

    /**
     * 查询市政工程详情
     */
    @Override
    public ZEngineeringCityInfoVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询市政工程详情列表
     */
    @Override
    public TableDataInfo<ZEngineeringCityInfoVo> queryPageList(ZEngineeringCityInfoBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringCityInfo> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringCityInfoVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询市政工程详情列表
     */
    @Override
    public List<ZEngineeringCityInfoVo> queryList(ZEngineeringCityInfoBo bo) {
        LambdaQueryWrapper<ZEngineeringCityInfo> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringCityInfo> buildQueryWrapper(ZEngineeringCityInfoBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringCityInfo> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getEngInfoId()), ZEngineeringCityInfo::getEngInfoId, bo.getEngInfoId());
        lqw.eq(StringUtils.isNotBlank(bo.getEngType()), ZEngineeringCityInfo::getEngType, bo.getEngType());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildUnit()), ZEngineeringCityInfo::getBuildUnit, bo.getBuildUnit());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildUser()), ZEngineeringCityInfo::getBuildUser, bo.getBuildUser());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildPhone()), ZEngineeringCityInfo::getBuildPhone, bo.getBuildPhone());
        lqw.eq(StringUtils.isNotBlank(bo.getPsUnit()), ZEngineeringCityInfo::getPsUnit, bo.getPsUnit());
        lqw.eq(StringUtils.isNotBlank(bo.getPsUser()), ZEngineeringCityInfo::getPsUser, bo.getPsUser());
        lqw.eq(StringUtils.isNotBlank(bo.getPsPhone()), ZEngineeringCityInfo::getPsPhone, bo.getPsPhone());
        lqw.eq(StringUtils.isNotBlank(bo.getCheckUnit()), ZEngineeringCityInfo::getCheckUnit, bo.getCheckUnit());
        lqw.eq(StringUtils.isNotBlank(bo.getCheckUser()), ZEngineeringCityInfo::getCheckUser, bo.getCheckUser());
        lqw.eq(StringUtils.isNotBlank(bo.getCheckPhone()), ZEngineeringCityInfo::getCheckPhone, bo.getCheckPhone());
        return lqw;
    }

    /**
     * 新增市政工程详情
     */
    @Override
    public Boolean insertByBo(ZEngineeringCityInfoBo bo) {
        ZEngineeringCityInfo add = BeanUtil.toBean(bo, ZEngineeringCityInfo.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改市政工程详情
     */
    @Override
    public Boolean updateByBo(ZEngineeringCityInfoBo bo) {
        ZEngineeringCityInfo update = BeanUtil.toBean(bo, ZEngineeringCityInfo.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringCityInfo entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除市政工程详情
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
