package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringCivilInfoBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringCivilInfoVo;
import com.ruoyi.zdsz.domain.ZEngineeringCivilInfo;
import com.ruoyi.zdsz.mapper.ZEngineeringCivilInfoMapper;
import com.ruoyi.zdsz.service.IZEngineeringCivilInfoService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 民用工程详情信息Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringCivilInfoServiceImpl implements IZEngineeringCivilInfoService {

    private final ZEngineeringCivilInfoMapper baseMapper;

    /**
     * 查询民用工程详情信息
     */
    @Override
    public ZEngineeringCivilInfoVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询民用工程详情信息列表
     */
    @Override
    public TableDataInfo<ZEngineeringCivilInfoVo> queryPageList(ZEngineeringCivilInfoBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringCivilInfo> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringCivilInfoVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询民用工程详情信息列表
     */
    @Override
    public List<ZEngineeringCivilInfoVo> queryList(ZEngineeringCivilInfoBo bo) {
        LambdaQueryWrapper<ZEngineeringCivilInfo> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringCivilInfo> buildQueryWrapper(ZEngineeringCivilInfoBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringCivilInfo> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getEngInfoId()), ZEngineeringCivilInfo::getEngInfoId, bo.getEngInfoId());
        lqw.eq(StringUtils.isNotBlank(bo.getConstructUser()), ZEngineeringCivilInfo::getConstructUser, bo.getConstructUser());
        lqw.eq(StringUtils.isNotBlank(bo.getConstructAddre()), ZEngineeringCivilInfo::getConstructAddre, bo.getConstructAddre());
        lqw.eq(bo.getConstructTime() != null, ZEngineeringCivilInfo::getConstructTime, bo.getConstructTime());
        lqw.eq(StringUtils.isNotBlank(bo.getConstructAccordingDrawings()), ZEngineeringCivilInfo::getConstructAccordingDrawings, bo.getConstructAccordingDrawings());
        lqw.eq(StringUtils.isNotBlank(bo.getConstructPhone()), ZEngineeringCivilInfo::getConstructPhone, bo.getConstructPhone());
        lqw.eq(StringUtils.isNotBlank(bo.getMaterialQuality()), ZEngineeringCivilInfo::getMaterialQuality, bo.getMaterialQuality());
        lqw.eq(StringUtils.isNotBlank(bo.getSpecifications()), ZEngineeringCivilInfo::getSpecifications, bo.getSpecifications());
        lqw.eq(bo.getSize() != null, ZEngineeringCivilInfo::getSize, bo.getSize());
        lqw.eq(bo.getNumber() != null, ZEngineeringCivilInfo::getNumber, bo.getNumber());
        lqw.eq(StringUtils.isNotBlank(bo.getSegmentedCompressionQualified()), ZEngineeringCivilInfo::getSegmentedCompressionQualified, bo.getSegmentedCompressionQualified());
        lqw.eq(bo.getBackfillTime() != null, ZEngineeringCivilInfo::getBackfillTime, bo.getBackfillTime());
        return lqw;
    }

    /**
     * 新增民用工程详情信息
     */
    @Override
    public Boolean insertByBo(ZEngineeringCivilInfoBo bo) {
        ZEngineeringCivilInfo add = BeanUtil.toBean(bo, ZEngineeringCivilInfo.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改民用工程详情信息
     */
    @Override
    public Boolean updateByBo(ZEngineeringCivilInfoBo bo) {
        ZEngineeringCivilInfo update = BeanUtil.toBean(bo, ZEngineeringCivilInfo.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringCivilInfo entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除民用工程详情信息
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
