package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringIndustrialInfoBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringIndustrialInfoVo;
import com.ruoyi.zdsz.domain.ZEngineeringIndustrialInfo;
import com.ruoyi.zdsz.mapper.ZEngineeringIndustrialInfoMapper;
import com.ruoyi.zdsz.service.IZEngineeringIndustrialInfoService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 工业工程详情Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringIndustrialInfoServiceImpl implements IZEngineeringIndustrialInfoService {

    private final ZEngineeringIndustrialInfoMapper baseMapper;

    /**
     * 查询工业工程详情
     */
    @Override
    public ZEngineeringIndustrialInfoVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询工业工程详情列表
     */
    @Override
    public TableDataInfo<ZEngineeringIndustrialInfoVo> queryPageList(ZEngineeringIndustrialInfoBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringIndustrialInfo> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringIndustrialInfoVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询工业工程详情列表
     */
    @Override
    public List<ZEngineeringIndustrialInfoVo> queryList(ZEngineeringIndustrialInfoBo bo) {
        LambdaQueryWrapper<ZEngineeringIndustrialInfo> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringIndustrialInfo> buildQueryWrapper(ZEngineeringIndustrialInfoBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringIndustrialInfo> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getEngInfoId()), ZEngineeringIndustrialInfo::getEngInfoId, bo.getEngInfoId());
        lqw.eq(StringUtils.isNotBlank(bo.getEngType()), ZEngineeringIndustrialInfo::getEngType, bo.getEngType());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildUnit()), ZEngineeringIndustrialInfo::getBuildUnit, bo.getBuildUnit());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildUser()), ZEngineeringIndustrialInfo::getBuildUser, bo.getBuildUser());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildPhone()), ZEngineeringIndustrialInfo::getBuildPhone, bo.getBuildPhone());
        lqw.eq(StringUtils.isNotBlank(bo.getPsUnit()), ZEngineeringIndustrialInfo::getPsUnit, bo.getPsUnit());
        lqw.eq(StringUtils.isNotBlank(bo.getPsUser()), ZEngineeringIndustrialInfo::getPsUser, bo.getPsUser());
        lqw.eq(StringUtils.isNotBlank(bo.getPsPhone()), ZEngineeringIndustrialInfo::getPsPhone, bo.getPsPhone());
        lqw.eq(StringUtils.isNotBlank(bo.getCheckUnit()), ZEngineeringIndustrialInfo::getCheckUnit, bo.getCheckUnit());
        lqw.eq(StringUtils.isNotBlank(bo.getCheckUser()), ZEngineeringIndustrialInfo::getCheckUser, bo.getCheckUser());
        lqw.eq(StringUtils.isNotBlank(bo.getCheckPhone()), ZEngineeringIndustrialInfo::getCheckPhone, bo.getCheckPhone());
        return lqw;
    }

    /**
     * 新增工业工程详情
     */
    @Override
    public Boolean insertByBo(ZEngineeringIndustrialInfoBo bo) {
        ZEngineeringIndustrialInfo add = BeanUtil.toBean(bo, ZEngineeringIndustrialInfo.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改工业工程详情
     */
    @Override
    public Boolean updateByBo(ZEngineeringIndustrialInfoBo bo) {
        ZEngineeringIndustrialInfo update = BeanUtil.toBean(bo, ZEngineeringIndustrialInfo.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringIndustrialInfo entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除工业工程详情
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
