package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringInfrastructureInfoBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringInfrastructureInfoVo;
import com.ruoyi.zdsz.domain.ZEngineeringInfrastructureInfo;
import com.ruoyi.zdsz.mapper.ZEngineeringInfrastructureInfoMapper;
import com.ruoyi.zdsz.service.IZEngineeringInfrastructureInfoService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 基建工程详情Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringInfrastructureInfoServiceImpl implements IZEngineeringInfrastructureInfoService {

    private final ZEngineeringInfrastructureInfoMapper baseMapper;

    /**
     * 查询基建工程详情
     */
    @Override
    public ZEngineeringInfrastructureInfoVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询基建工程详情列表
     */
    @Override
    public TableDataInfo<ZEngineeringInfrastructureInfoVo> queryPageList(ZEngineeringInfrastructureInfoBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringInfrastructureInfo> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringInfrastructureInfoVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询基建工程详情列表
     */
    @Override
    public List<ZEngineeringInfrastructureInfoVo> queryList(ZEngineeringInfrastructureInfoBo bo) {
        LambdaQueryWrapper<ZEngineeringInfrastructureInfo> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringInfrastructureInfo> buildQueryWrapper(ZEngineeringInfrastructureInfoBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringInfrastructureInfo> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getEngInfoId()), ZEngineeringInfrastructureInfo::getEngInfoId, bo.getEngInfoId());
        lqw.like(StringUtils.isNotBlank(bo.getEngName()), ZEngineeringInfrastructureInfo::getEngName, bo.getEngName());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildPlace()), ZEngineeringInfrastructureInfo::getBuildPlace, bo.getBuildPlace());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildUnit()), ZEngineeringInfrastructureInfo::getBuildUnit, bo.getBuildUnit());
        lqw.eq(bo.getStartTime() != null, ZEngineeringInfrastructureInfo::getStartTime, bo.getStartTime());
        lqw.eq(bo.getPlanTime() != null, ZEngineeringInfrastructureInfo::getPlanTime, bo.getPlanTime());
        lqw.eq(bo.getWorkTime() != null, ZEngineeringInfrastructureInfo::getWorkTime, bo.getWorkTime());
        lqw.eq(StringUtils.isNotBlank(bo.getWorkContent()), ZEngineeringInfrastructureInfo::getWorkContent, bo.getWorkContent());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildModel()), ZEngineeringInfrastructureInfo::getBuildModel, bo.getBuildModel());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildChi()), ZEngineeringInfrastructureInfo::getBuildChi, bo.getBuildChi());
        lqw.eq(bo.getBuildMuch() != null, ZEngineeringInfrastructureInfo::getBuildMuch, bo.getBuildMuch());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildUserId()), ZEngineeringInfrastructureInfo::getBuildUserId, bo.getBuildUserId());
        return lqw;
    }

    /**
     * 新增基建工程详情
     */
    @Override
    public Boolean insertByBo(ZEngineeringInfrastructureInfoBo bo) {
        ZEngineeringInfrastructureInfo add = BeanUtil.toBean(bo, ZEngineeringInfrastructureInfo.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改基建工程详情
     */
    @Override
    public Boolean updateByBo(ZEngineeringInfrastructureInfoBo bo) {
        ZEngineeringInfrastructureInfo update = BeanUtil.toBean(bo, ZEngineeringInfrastructureInfo.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringInfrastructureInfo entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除基建工程详情
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
