package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringMaterialPresetBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringMaterialPresetVo;
import com.ruoyi.zdsz.domain.ZEngineeringMaterialPreset;
import com.ruoyi.zdsz.mapper.ZEngineeringMaterialPresetMapper;
import com.ruoyi.zdsz.service.IZEngineeringMaterialPresetService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 工程用料预设Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringMaterialPresetServiceImpl implements IZEngineeringMaterialPresetService {

    private final ZEngineeringMaterialPresetMapper baseMapper;

    /**
     * 查询工程用料预设
     */
    @Override
    public ZEngineeringMaterialPresetVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询工程用料预设列表
     */
    @Override
    public TableDataInfo<ZEngineeringMaterialPresetVo> queryPageList(ZEngineeringMaterialPresetBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringMaterialPreset> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringMaterialPresetVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询工程用料预设列表
     */
    @Override
    public List<ZEngineeringMaterialPresetVo> queryList(ZEngineeringMaterialPresetBo bo) {
        LambdaQueryWrapper<ZEngineeringMaterialPreset> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringMaterialPreset> buildQueryWrapper(ZEngineeringMaterialPresetBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringMaterialPreset> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getAreaId()), ZEngineeringMaterialPreset::getAreaId, bo.getAreaId());
        lqw.eq(StringUtils.isNotBlank(bo.getGoodsKind()), ZEngineeringMaterialPreset::getGoodsKind, bo.getGoodsKind());
        lqw.eq(StringUtils.isNotBlank(bo.getPlanGui()), ZEngineeringMaterialPreset::getPlanGui, bo.getPlanGui());
        lqw.eq(StringUtils.isNotBlank(bo.getRealGui()), ZEngineeringMaterialPreset::getRealGui, bo.getRealGui());
        lqw.eq(bo.getRealMoney() != null, ZEngineeringMaterialPreset::getRealMoney, bo.getRealMoney());
        lqw.eq(bo.getPlanMoney() != null, ZEngineeringMaterialPreset::getPlanMoney, bo.getPlanMoney());
        lqw.eq(StringUtils.isNotBlank(bo.getPlanSize()), ZEngineeringMaterialPreset::getPlanSize, bo.getPlanSize());
        lqw.eq(StringUtils.isNotBlank(bo.getRealSzie()), ZEngineeringMaterialPreset::getRealSzie, bo.getRealSzie());
        return lqw;
    }

    /**
     * 新增工程用料预设
     */
    @Override
    public Boolean insertByBo(ZEngineeringMaterialPresetBo bo) {
        ZEngineeringMaterialPreset add = BeanUtil.toBean(bo, ZEngineeringMaterialPreset.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改工程用料预设
     */
    @Override
    public Boolean updateByBo(ZEngineeringMaterialPresetBo bo) {
        ZEngineeringMaterialPreset update = BeanUtil.toBean(bo, ZEngineeringMaterialPreset.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringMaterialPreset entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除工程用料预设
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
