package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringPipeJackingInfoBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringPipeJackingInfoVo;
import com.ruoyi.zdsz.domain.ZEngineeringPipeJackingInfo;
import com.ruoyi.zdsz.mapper.ZEngineeringPipeJackingInfoMapper;
import com.ruoyi.zdsz.service.IZEngineeringPipeJackingInfoService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 顶管工程详情Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringPipeJackingInfoServiceImpl implements IZEngineeringPipeJackingInfoService {

    private final ZEngineeringPipeJackingInfoMapper baseMapper;

    /**
     * 查询顶管工程详情
     */
    @Override
    public ZEngineeringPipeJackingInfoVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询顶管工程详情列表
     */
    @Override
    public TableDataInfo<ZEngineeringPipeJackingInfoVo> queryPageList(ZEngineeringPipeJackingInfoBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringPipeJackingInfo> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringPipeJackingInfoVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询顶管工程详情列表
     */
    @Override
    public List<ZEngineeringPipeJackingInfoVo> queryList(ZEngineeringPipeJackingInfoBo bo) {
        LambdaQueryWrapper<ZEngineeringPipeJackingInfo> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringPipeJackingInfo> buildQueryWrapper(ZEngineeringPipeJackingInfoBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringPipeJackingInfo> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getEngInfoId()), ZEngineeringPipeJackingInfo::getEngInfoId, bo.getEngInfoId());
        lqw.like(StringUtils.isNotBlank(bo.getEngName()), ZEngineeringPipeJackingInfo::getEngName, bo.getEngName());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildPlace()), ZEngineeringPipeJackingInfo::getBuildPlace, bo.getBuildPlace());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildCode()), ZEngineeringPipeJackingInfo::getBuildCode, bo.getBuildCode());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildUnit()), ZEngineeringPipeJackingInfo::getBuildUnit, bo.getBuildUnit());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildModel()), ZEngineeringPipeJackingInfo::getBuildModel, bo.getBuildModel());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildMg()), ZEngineeringPipeJackingInfo::getBuildMg, bo.getBuildMg());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildUserId()), ZEngineeringPipeJackingInfo::getBuildUserId, bo.getBuildUserId());
        lqw.eq(bo.getBuildTime() != null, ZEngineeringPipeJackingInfo::getBuildTime, bo.getBuildTime());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildProcess()), ZEngineeringPipeJackingInfo::getBuildProcess, bo.getBuildProcess());
        return lqw;
    }

    /**
     * 新增顶管工程详情
     */
    @Override
    public Boolean insertByBo(ZEngineeringPipeJackingInfoBo bo) {
        ZEngineeringPipeJackingInfo add = BeanUtil.toBean(bo, ZEngineeringPipeJackingInfo.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改顶管工程详情
     */
    @Override
    public Boolean updateByBo(ZEngineeringPipeJackingInfoBo bo) {
        ZEngineeringPipeJackingInfo update = BeanUtil.toBean(bo, ZEngineeringPipeJackingInfo.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringPipeJackingInfo entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除顶管工程详情
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
