package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringVo;
import com.ruoyi.zdsz.domain.ZEngineering;
import com.ruoyi.zdsz.mapper.ZEngineeringMapper;
import com.ruoyi.zdsz.service.IZEngineeringService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 工程管理Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-23
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringServiceImpl implements IZEngineeringService {

    private final ZEngineeringMapper baseMapper;

    /**
     * 查询工程管理
     */
    @Override
    public ZEngineeringVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询工程管理列表
     */
    @Override
    public TableDataInfo<ZEngineeringVo> queryPageList(ZEngineeringBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineering> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询工程管理列表
     */
    @Override
    public List<ZEngineeringVo> queryList(ZEngineeringBo bo) {
        LambdaQueryWrapper<ZEngineering> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineering> buildQueryWrapper(ZEngineeringBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineering> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getAreaId()), ZEngineering::getAreaId, bo.getAreaId());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildingId()), ZEngineering::getBuildingId, bo.getBuildingId());
        lqw.eq(StringUtils.isNotBlank(bo.getUnitId()), ZEngineering::getUnitId, bo.getUnitId());
        lqw.eq(StringUtils.isNotBlank(bo.getHouseId()), ZEngineering::getHouseId, bo.getHouseId());
        lqw.eq(StringUtils.isNotBlank(bo.getEngineeringType()), ZEngineering::getEngineeringType, bo.getEngineeringType());
        lqw.like(StringUtils.isNotBlank(bo.getHeadName()), ZEngineering::getHeadName, bo.getHeadName());
        lqw.eq(StringUtils.isNotBlank(bo.getHeadPhone()), ZEngineering::getHeadPhone, bo.getHeadPhone());
        lqw.eq(StringUtils.isNotBlank(bo.getEngineeringClassification()), ZEngineering::getEngineeringClassification, bo.getEngineeringClassification());
        return lqw;
    }

    /**
     * 新增工程管理
     */
    @Override
    public Boolean insertByBo(ZEngineeringBo bo) {
        ZEngineering add = BeanUtil.toBean(bo, ZEngineering.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改工程管理
     */
    @Override
    public Boolean updateByBo(ZEngineeringBo bo) {
        ZEngineering update = BeanUtil.toBean(bo, ZEngineering.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineering entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除工程管理
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
